/************************************************************************/
/*									*/
/*	Title		:	RockForce SideBand API			*/
/*									*/
/*	Author		:	N.P.Vassallo				*/
/*									*/
/*	Creation	:	23rd December 2004			*/
/*									*/
/*	Description	:	Function Prototypes and Structures.	*/
/*									*/
/************************************************************************/

/* History...

1.0.0	23-Dec-04	NPV	Creation.

*/

/*****************************************************************************
*******************************                 ******************************
*******************************   Definitions   ******************************
*******************************                 ******************************
*****************************************************************************/

/*
** SideBand I/O Structure...
*/

#define	RF_MAX_PORT	8			/* Maximum number of supported ports */

#define	SB_UART_ADDR		0x0000		/* 0x0000 UARTs Base Address */
#define		SB_UART_STRIDE		1	/*	  Each register uses 1 bytes */
#define		SB_UART_SPAN		8	/*        UART register span */

#define	SB_INT_LATCH_ADDR	0x0060		/* 0x0060 Interrupt Latch Register */

#define	SB_1WIRE_ADDR		0x0068		/* 0x0068 1-Wire Interface */
#define		SB_1WIRE_CMD	SB_1WIRE_ADDR+0	/*	  1-Wire Command Register */
#define		SB_1WIRE_TX	SB_1WIRE_ADDR+1	/*	  1-Wire Write Register */
#define		SB_1WIRE_RX	SB_1WIRE_ADDR+1	/*	  1-Wire Read Register */
#define		SB_1WIRE_STAT	SB_1WIRE_ADDR+2	/*	  1-Wire Status Register */

#define	SB_RESET_ADDR		0x0078		/* 0x0078 Reset Register Address */

/*
** 1-Wire Commands...
*/

#define		SB_1WIRE_RESET		0x01
#define		SB_1WIRE_READ_ROM	0x33
#define		SB_1WIRE_READ		0xFF

/*
** 1-Wire Status Register definitions... 
*/

#define		SB_1WIRE_OW_LOW		0x80	/*	  1-Wire One Wire Low */
#define		SB_1WIRE_OW_SHORT	0x40	/*	  1-Wire One Wire Short */
#define		SB_1WIRE_RSRF		0x20	/*	  1-Wire Receive Shift Register Full */
#define		SB_1WIRE_RBF		0x10	/*	  1-Wire Receive Buffer Full */
#define		SB_1WIRE_TEMT		0x08	/*	  1-Wire Transmit Shift Register Empty */
#define		SB_1WIRE_TBE		0x04	/*	  1-Wire Transmit Buffer Empty */
#define		SB_1WIRE_PDR		0x02	/*	  1-Wire Presence Detect Result */
#define		SB_1WIRE_PD		0x01	/*	  1-Wire Presence Detect */

/*****************************************************************************
*******************************                *******************************
*******************************   Structures   *******************************
*******************************                *******************************
*****************************************************************************/

struct serial_struct 
{
	int		type;
	int		line;
	int		port;
	int		irq;
	int		flags;
	int		xmit_fifo_size;
	int		custom_divisor;
	int		baud_base;
	unsigned short	close_delay;
	char		io_type;
	char		reserved_char[1];
	int		hub6;
	unsigned short	closing_wait; /* time to wait before closing */
	unsigned short	closing_wait2; /* no longer used... */
	unsigned char	*iomem_base;
	unsigned short	iomem_reg_shift;
	int		reserved[2];
};

struct serial_multiport_struct 
{
	int		irq;
	int		port1;
	unsigned char	mask1, match1;
	int		port2;
	unsigned char	mask2, match2;
	int		port3;
	unsigned char	mask3, match3;
	int		port4;
	unsigned char	mask4, match4;
	int		port_monitor;
	int		reserved[32];
};

/*****************************************************************************
*******************************                 ******************************
*******************************   Error Codes   ******************************
*******************************                 ******************************
*****************************************************************************/

#define	RF_SUCCESS			0
#define	RF_INVALID_PARAMETER		1
#define	RF_INVALID_PORT			2
#define	RF_INVALID_BUFFER		3
#define	RF_INVALID_REGISTER		4
#define	RF_INVALID_ADDRESS		5
#define	RF_INVALID_MODE			6
#define	RF_BUFFER_TOO_SMALL		7
#define	RF_SERIAL_NUMBER_BAD_CRC	8
#define	RF_FAILURE			100

/*****************************************************************************
****************************                      ****************************
****************************   UART Definitions   ****************************
****************************                      ****************************
*****************************************************************************/

/*
** Standard registers...
*/

#define	UART_THR		0x00		/* (WO) Transmit Holding Register */
#define	UART_RBR		0x00		/* (RO) Receive Buffer Register */
#define	UART_IER		0x01		/* (RW) Interrupt Enable Register */
#define	UART_FCR		0x02		/* (WO) FIFO Control Register */
#define	UART_ISR		0x02		/* (RO) Interrupt Status Register */
#define	UART_LCR		0x03		/* (RW) Line Control Register */
#define	UART_MCR		0x04		/* (RW) Modem Control Register */
#define	UART_LSR		0x05		/* (RW) Line Status Register */
#define	UART_MSR		0x06		/* (RW) Modem Status Register */
#define	UART_SCR		0x07		/* (RW) SCratchpad Register */

/*
** Special registers...
*/

#define	UART_DLL		0x10		/* (RW) Divisor Latch Least significant */
#define	UART_DLM		0x11		/* (RW) Divisor Latch Most significant */

#define	UART_REG_MASK		0x0F		/* Register Mask */
#define		LCR_DLAB		0x80	/*	Divisor Latch Access Bit */
#define	UART_MCX		0x04		/* Modem Control Xtras */
#define		MCX_SCRREAD		0x01	/* Scratchpad is readable */

/*****************************************************************************
*******************************                *******************************
*******************************   Prototypes   *******************************
*******************************                *******************************
*****************************************************************************/

_u32	RockForcePortReadUARTReg(_u32 hDevice,_u32 Port,_u32 Reg,pu8 pValue);
_u32	RockForcePortWriteUARTReg(_u32 hDevice,_u32 Port,_u32 Reg,_u8 Value);
_u32	RockForceReadSerialNumber(_u32 hDevice,pu8 pBuffer,_u32 BufLen,pu32 pBytesRead);
_u32	RockForcePortReset(_u32 hDevice,_u32 Port,_u32 Mode);
_u32	RockForceGetErrorString(_u32 Error,pu8 pBuffer,_u32 BufLen);

/* RockForcePortModifyUARTReg definitions... */
#define	OP_AND		1
#define	OP_OR		2
#define	OP_XOR		3
#define	OP_AND_OR	4

/* RockForcePortReset definitions... */
#define	RESET_ONLY	0
#define	RESET_OPENCHECK	1
#define	RESET_OPENFORCE	2

/* End of RFSBAPI.H */
